import { select, csv, scaleLinear, max, scaleBand, axisLeft, axisBottom } from 'd3';

var svg = d3.select('svg');

/*Grabs values from index.html to set total area for svg*/
const height = parseFloat(svg.attr('height')); 
const width = parseFloat(svg.attr('width'));


/* Renders the chart using the data */
const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 80, right: 50, bottom: 50, left: 100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)]) /* Max value from data */
  	.range([0, innerWidth]); /* Max screen area for the axis */
  
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight]) /* Max screen area for the axis */
  	.padding(0.1);
  
	const title = svg.append('text')
  	.attr('class', 'titleText')
    .attr('x', width/2)
    .attr('y', 0 + (margin.top/(1.5)))
    .attr('text-anchor', 'middle')
    .text('Most Populous Countries - 2018 Data');
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
 
  	
  
  g.selectAll('rect').data(data) /* Selects all rectangles on the page */
  	.enter()
    .append('rect')
  		.attr('class','bars')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', yScale.bandwidth())
  		.style('opacity', 0.7)
  		.style('stroke','none')
  		.attr('fill', d => {
    		if (d.population > 1000000000) {
          return "#C70039";
        }
    		else if (d.population > 200000000) {
          return "#FF5733";
        }
    		else if (d.population > 150000000) {
          return "#FFC300";
        }
    		return "#bbc93a";
  		})
  
    
  // Text shows 'undefined' instead of the data. Not sure how to fix this //
  
  		.on('mouseover', function(d){
    		d3.select('#tooltip')
    			.style('opacity', 1)
  			d3.select(this)
  				//.style('stroke','black')
  				.style('opacity',1)})

      .on('mousemove', function(d){
      	d3.select('#tooltip')
    			.text(`${xValue(d)}, ${yValue(d)}`)
        	.style('transform',`translate(${event.layerX - 130}px, ${event.layerY-30}px)`)})
  
  		.on('mouseout', function(d){
    		d3.select('#tooltip')
    			.style('opacity', 0)
        d3.select(this)
  				//.style('stroke','none')
  				.style('opacity',0.7)})
  
  // Append axes //

  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  // Tooltip rendered last to be on top layer //
  
const tooltip = d3.select('g')
	.append('text')
  	.attr('id', 'tooltip')
  	.style('position','absolute')
    //.attr('r',30)
  	//.attr('fill','blue')
  	.style('opacity',0);
};





/* csv returns a promise that resolves when the data is loaded */
/* Parses csv into array of objects */
csv('data.csv').then(data => {
  data.forEach(d => {
  	d.population = +d.population * 1000; 
    /* function to turn strings from population column in csv into float values */
  });
 render(data); 
});